<font size="+1">

AeroMAPS est un modèle permettant d'effectuer une évaluation multidisciplinaire de scénarios prospectifs pour le 
transport aérien. Il permet par exemple de simuler et d'analyser des scénarios pour réduire les impacts climatiques de 
l'aviation à travers des leviers d'action variés. Il est destiné à devenir un modèle d'évaluation intégrée (IAM pour 
*Integrated Assessment Model*)  sectoriel prenant en compte des considérations technologiques, environnementales, 
sociologiques, économiques et autres. Il vise à évaluer la durabilité de scénarios de transition simulés pour le 
transport aérien sur la base de multiples critères.

Une <u><a href="https://aeromaps.github.io/AeroMAPS/intro.html" target="_blank">documentation</a></u> (en anglais) est
disponible pour plus de détails sur AeroMAPS. Plus spécifiquement, ce site web héberge une interface graphique pour
faciliter la prise en main du modèle. Un tutoriel dédié et les différents réglages utilisés sur cette interface peuvent 
être directement trouvé 
<u><a href="https://aeromaps.github.io/AeroMAPS/books/documentation_gui.html" target="_blank">ici</a></u>.

Le code source d'AeroMAPS est disponible sur un 
<u><a href="https://github.com/AeroMAPS/AeroMAPS" target="_blank">dépôt GitHub</a></u>.

AeroMAPS est sous licence
<u><a href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GPL-3.0</a></u>.

</font>